@@ -31,7 +31,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <curses.h>
+#include <ncursesw/curses.h>
 #include <signal.h>
 
 #include "i18n.hh"
